@@ -49,12 +49,13 @@ class AgentException(Exception):
     
 class Agent():
 
-    def __init__(self, auto_login=True, auto_connect=True, loop=None, register=True,  with_monitor=True, **kwargs) -> None:
+    def __init__(self, auto_login=True, auto_connect=True, loop=None, register=True,  with_monitor=False, **kwargs) -> None:
         self.auto_login = auto_login
         self.auto_connect = auto_connect
 
-        self.herre = get_current_herre() 
-        self.loop = get_current_herre().loop
+        self.herre = get_current_herre(**kwargs) 
+        self.loop = self.herre.loop
+        
         self.ward: ArkitektWard = get_ward_registry().get_ward_instance("arkitekt")
         self.monitor = Monitor("Agent") if with_monitor else None
         self.panel = self.monitor.create_agent_panel(self) if self.monitor else None
@@ -67,7 +68,7 @@ class Agent():
             set_current_agent(self)
 
 
-        super().__init__(**kwargs)
+        super().__init__()
 
 
     @property
